==> scalar__postman-to-openapi-0.3.5.jar: META-INF/resources/webjars/scalar__postman-to-openapi/0.3.5/CHANGELOG.md <==
# @scalar/postman-to-openapi

## 0.3.5

### Patch Changes

- Updated dependencies [7ca47ab]
  - @scalar/oas-utils@0.4.2

## 0.3.4

### Patch Changes

- @scalar/oas-utils@0.4.1

## 0.3.3

### Patch Changes

- Updated dependencies [1e87feb]
- Updated dependencies [cad6277]
  - @scalar/oas-utils@0.4.0
  - @scalar/openapi-types@0.3.1

## 0.3.2

### Patch Changes

- Updated dependencies [151ef09]
- Updated dependencies [442c0a3]
  - @scalar/oas-utils@0.3.2

## 0.3.1

### Patch Changes

- Updated dependencies [4440949]
  - @scalar/oas-utils@0.3.1
  - @scalar/openapi-types@0.3.1

## 0.3.0

### Minor Changes

- 483ca93: chore: require Node 20 (or above)

### Patch Changes

- Updated dependencies [30bab1d]
- Updated dependencies [483ca93]
  - @scalar/oas-utils@0.3.0
  - @scalar/openapi-types@0.3.0

## 0.2.17

### Patch Changes

- @scalar/oas-utils@0.2.144

## 0.2.16

### Patch Changes

- Updated dependencies [cb9428c]
- Updated dependencies [67aa0f4]
  - @scalar/openapi-types@0.2.3
  - @scalar/oas-utils@0.2.143

## 0.2.15

### Patch Changes

- Updated dependencies [cd6cf24]
  - @scalar/oas-utils@0.2.142

## 0.2.14

### Patch Changes

- 8c7bad8: chore: move build tooling to esbuild
- Updated dependencies [8c7bad8]
  - @scalar/openapi-types@0.2.2
  - @scalar/oas-utils@0.2.141

## 0.2.13

### Patch Changes

- Updated dependencies [e8457cb]
  - @scalar/oas-utils@0.2.140

## 0.2.12

### Patch Changes

- Updated dependencies [d2f27f4]
  - @scalar/oas-utils@0.2.139

## 0.2.11

### Patch Changes

- Updated dependencies [5d24800]
  - @scalar/oas-utils@0.2.138

## 0.2.10

### Patch Changes

- @scalar/oas-utils@0.2.137
- @scalar/openapi-types@0.2.1

## 0.2.9

### Patch Changes

- Updated dependencies [eb4854d]
  - @scalar/oas-utils@0.2.136

## 0.2.8

### Patch Changes

- Updated dependencies [fa8ed84]
- Updated dependencies [fa8ed84]
- Updated dependencies [8d54857]
  - @scalar/openapi-types@0.2.1
  - @scalar/oas-utils@0.2.135

## 0.2.7

### Patch Changes

- @scalar/oas-utils@0.2.134

## 0.2.6

### Patch Changes

- Updated dependencies [e489824]
  - @scalar/oas-utils@0.2.133

## 0.2.5

### Patch Changes

- Updated dependencies [c5047ee]
  - @scalar/oas-utils@0.2.132

## 0.2.4

### Patch Changes

- Updated dependencies [4abe4f8]
  - @scalar/oas-utils@0.2.131

## 0.2.3

### Patch Changes

- @scalar/oas-utils@0.2.130

## 0.2.2

### Patch Changes

- @scalar/oas-utils@0.2.129

## 0.2.1

### Patch Changes

- Updated dependencies [18b1be9]
  - @scalar/oas-utils@0.2.128

## 0.2.0

### Minor Changes

- 018e8b2: feat: import Postman post-response scripts

### Patch Changes

- 018e8b2: feat: cleaner Postman import (no 'default' tag, no made up responses)
- 018e8b2: fix: /raw and / paths are handled specifically
- Updated dependencies [bf961b1]
- Updated dependencies [a176b7e]
  - @scalar/oas-utils@0.2.127

## 0.1.49

### Patch Changes

- Updated dependencies [a571d36]
  - @scalar/oas-utils@0.2.126

## 0.1.48

### Patch Changes

- Updated dependencies [e62e677]
- Updated dependencies [e62e677]
- Updated dependencies [82f16a5]
- Updated dependencies [04e27a1]
- Updated dependencies [846d015]
  - @scalar/openapi-types@0.2.0
  - @scalar/oas-utils@0.2.125

## 0.1.47

### Patch Changes

- Updated dependencies [0de80ae]
  - @scalar/oas-utils@0.2.124

## 0.1.46

### Patch Changes

- Updated dependencies [52f6f4c]
  - @scalar/oas-utils@0.2.123

## 0.1.45

### Patch Changes

- @scalar/oas-utils@0.2.122

## 0.1.44

### Patch Changes

- Updated dependencies [0f13162]
- Updated dependencies [0212daa]
  - @scalar/oas-utils@0.2.121

## 0.1.43

### Patch Changes

- Updated dependencies [cd75eeb]
  - @scalar/oas-utils@0.2.120

## 0.1.42

### Patch Changes

- @scalar/oas-utils@0.2.119

## 0.1.41

### Patch Changes

- @scalar/oas-utils@0.2.118

## 0.1.40

### Patch Changes

- @scalar/oas-utils@0.2.117

## 0.1.39

### Patch Changes

- Updated dependencies [ab98841]
- Updated dependencies [db9ebbc]
  - @scalar/oas-utils@0.2.116

## 0.1.38

### Patch Changes

- @scalar/oas-utils@0.2.115

## 0.1.37

### Patch Changes

- Updated dependencies [fb22645]
  - @scalar/oas-utils@0.2.114

## 0.1.36

### Patch Changes

- Updated dependencies [a31973c]
  - @scalar/oas-utils@0.2.113

## 0.1.35

### Patch Changes

- @scalar/oas-utils@0.2.112

## 0.1.34

### Patch Changes

- Updated dependencies [89d8b75]
- Updated dependencies [8a04b8d]
- Updated dependencies [1459ce7]
- Updated dependencies [8a04b8d]
  - @scalar/oas-utils@0.2.111
  - @scalar/openapi-types@0.1.9

## 0.1.33

### Patch Changes

- @scalar/oas-utils@0.2.110

## 0.1.32

### Patch Changes

- Updated dependencies [4db5161]
  - @scalar/oas-utils@0.2.109

## 0.1.31

### Patch Changes

- Updated dependencies [9fc97da]
- Updated dependencies [12088f1]
- Updated dependencies [c10bbf5]
  - @scalar/oas-utils@0.2.108
  - @scalar/openapi-types@0.1.9

## 0.1.30

### Patch Changes

- Updated dependencies [e350f23]
- Updated dependencies [738d21c]
  - @scalar/openapi-types@0.1.8
  - @scalar/oas-utils@0.2.107

## 0.1.29

### Patch Changes

- Updated dependencies [ed92564]
  - @scalar/oas-utils@0.2.106

## 0.1.28

### Patch Changes

- fa6afe8: chore: code formatting
- 1223c1f: chore: code style
- Updated dependencies [54fdfcb]
  - @scalar/oas-utils@0.2.105
  - @scalar/openapi-types@0.1.7

## 0.1.27

### Patch Changes

- Updated dependencies [f500435]
- Updated dependencies [da5cf08]
- Updated dependencies [b5727ef]
- Updated dependencies [4de3124]
- Updated dependencies [34e6f52]
  - @scalar/oas-utils@0.2.104

## 0.1.26

### Patch Changes

- Updated dependencies [0f5df68]
- Updated dependencies [937f791]
  - @scalar/oas-utils@0.2.103

## 0.1.25

### Patch Changes

- Updated dependencies [a34f834]
- Updated dependencies [ef98b9c]
- Updated dependencies [a34f834]
- Updated dependencies [ebdf762]
- Updated dependencies [f9bf5f1]
  - @scalar/oas-utils@0.2.102
  - @scalar/openapi-types@0.1.7

## 0.1.24

### Patch Changes

- Updated dependencies [be34e7d]
  - @scalar/oas-utils@0.2.101

## 0.1.23

### Patch Changes

- Updated dependencies [12e7232]
- Updated dependencies [901970f]
- Updated dependencies [f1f39b0]
  - @scalar/oas-utils@0.2.100

## 0.1.22

### Patch Changes

- Updated dependencies [c803e2d]
  - @scalar/oas-utils@0.2.99

## 0.1.21

### Patch Changes

- @scalar/oas-utils@0.2.98

## 0.1.20

### Patch Changes

- Updated dependencies [7df4472]
- Updated dependencies [13333e6]
  - @scalar/oas-utils@0.2.97
  - @scalar/openapi-types@0.1.6

## 0.1.19

### Patch Changes

- Updated dependencies [cf0e7b1]
  - @scalar/oas-utils@0.2.96

## 0.1.18

### Patch Changes

- Updated dependencies [3156ecd]
  - @scalar/oas-utils@0.2.95

## 0.1.17

### Patch Changes

- Updated dependencies [a36fada]
  - @scalar/oas-utils@0.2.94

## 0.1.16

### Patch Changes

- Updated dependencies [ca2d98b]
  - @scalar/oas-utils@0.2.93

## 0.1.15

### Patch Changes

- Updated dependencies [02b4201]
  - @scalar/oas-utils@0.2.92

## 0.1.14

### Patch Changes

- @scalar/oas-utils@0.2.91

## 0.1.13

### Patch Changes

- Updated dependencies [573d113]
- Updated dependencies [c263aaf]
  - @scalar/oas-utils@0.2.90

## 0.1.12

### Patch Changes

- @scalar/oas-utils@0.2.89

## 0.1.11

### Patch Changes

- @scalar/oas-utils@0.2.88

## 0.1.10

### Patch Changes

- Updated dependencies [8017ff9]
  - @scalar/oas-utils@0.2.87

## 0.1.9

### Patch Changes

- Updated dependencies [3eb0d11]
- Updated dependencies [b66a85c]
  - @scalar/oas-utils@0.2.86

## 0.1.8

### Patch Changes

- eeb2a8b: fix: postman examples are misinterpreted as folders
- Updated dependencies [3b4a788]
- Updated dependencies [4c5be96]
- Updated dependencies [4c5be96]
  - @scalar/oas-utils@0.2.85

## 0.1.7

### Patch Changes

- Updated dependencies [9b4f85d]
  - @scalar/oas-utils@0.2.84

## 0.1.6

### Patch Changes

- Updated dependencies [f524411]
- Updated dependencies [10c9016]
- Updated dependencies [b11294c]
  - @scalar/oas-utils@0.2.83

## 0.1.5

### Patch Changes

- Updated dependencies [6389557]
  - @scalar/oas-utils@0.2.82

## 0.1.4

### Patch Changes

- @scalar/oas-utils@0.2.81

## 0.1.3

### Patch Changes

- @scalar/oas-utils@0.2.80

## 0.1.2

### Patch Changes

- Updated dependencies [6dd7eda]
  - @scalar/oas-utils@0.2.79

## 0.1.1

### Patch Changes

- Updated dependencies [daa2663]
- Updated dependencies [37abd4f]
  - @scalar/oas-utils@0.2.78

## 0.1.0

### Minor Changes

- a0bcd23: hello world :)

### Patch Changes

- Updated dependencies [44a7100]
  - @scalar/oas-utils@0.2.77

==> scalar__postman-to-openapi-0.3.7.jar: META-INF/resources/webjars/scalar__postman-to-openapi/0.3.7/CHANGELOG.md <==
# @scalar/postman-to-openapi

## 0.3.7

### Patch Changes

- Updated dependencies [8bc9f20]
  - @scalar/helpers@0.0.3
  - @scalar/oas-utils@0.4.4

## 0.3.6

### Patch Changes

- 8165b3b: feat(helpers): added new helpers package
- Updated dependencies [8165b3b]
- Updated dependencies [05c22c7]
  - @scalar/oas-utils@0.4.3
  - @scalar/helpers@0.0.2
  - @scalar/openapi-types@0.3.2

## 0.3.5

### Patch Changes

- Updated dependencies [7ca47ab]
  - @scalar/oas-utils@0.4.2

## 0.3.4

### Patch Changes

- @scalar/oas-utils@0.4.1

## 0.3.3

### Patch Changes

- Updated dependencies [1e87feb]
- Updated dependencies [cad6277]
  - @scalar/oas-utils@0.4.0
  - @scalar/openapi-types@0.3.1

## 0.3.2

### Patch Changes

- Updated dependencies [151ef09]
- Updated dependencies [442c0a3]
  - @scalar/oas-utils@0.3.2

## 0.3.1

### Patch Changes

- Updated dependencies [4440949]
  - @scalar/oas-utils@0.3.1
  - @scalar/openapi-types@0.3.1

## 0.3.0

### Minor Changes

- 483ca93: chore: require Node 20 (or above)

### Patch Changes

- Updated dependencies [30bab1d]
- Updated dependencies [483ca93]
  - @scalar/oas-utils@0.3.0
  - @scalar/openapi-types@0.3.0

## 0.2.17

### Patch Changes

- @scalar/oas-utils@0.2.144

## 0.2.16

### Patch Changes

- Updated dependencies [cb9428c]
- Updated dependencies [67aa0f4]
  - @scalar/openapi-types@0.2.3
  - @scalar/oas-utils@0.2.143

## 0.2.15

### Patch Changes

- Updated dependencies [cd6cf24]
  - @scalar/oas-utils@0.2.142

## 0.2.14

### Patch Changes

- 8c7bad8: chore: move build tooling to esbuild
- Updated dependencies [8c7bad8]
  - @scalar/openapi-types@0.2.2
  - @scalar/oas-utils@0.2.141

## 0.2.13

### Patch Changes

- Updated dependencies [e8457cb]
  - @scalar/oas-utils@0.2.140

## 0.2.12

### Patch Changes

- Updated dependencies [d2f27f4]
  - @scalar/oas-utils@0.2.139

## 0.2.11

### Patch Changes

- Updated dependencies [5d24800]
  - @scalar/oas-utils@0.2.138

## 0.2.10

### Patch Changes

- @scalar/oas-utils@0.2.137
- @scalar/openapi-types@0.2.1

## 0.2.9

### Patch Changes

- Updated dependencies [eb4854d]
  - @scalar/oas-utils@0.2.136

## 0.2.8

### Patch Changes

- Updated dependencies [fa8ed84]
- Updated dependencies [fa8ed84]
- Updated dependencies [8d54857]
  - @scalar/openapi-types@0.2.1
  - @scalar/oas-utils@0.2.135

## 0.2.7

### Patch Changes

- @scalar/oas-utils@0.2.134

## 0.2.6

### Patch Changes

- Updated dependencies [e489824]
  - @scalar/oas-utils@0.2.133

## 0.2.5

### Patch Changes

- Updated dependencies [c5047ee]
  - @scalar/oas-utils@0.2.132

## 0.2.4

### Patch Changes

- Updated dependencies [4abe4f8]
  - @scalar/oas-utils@0.2.131

## 0.2.3

### Patch Changes

- @scalar/oas-utils@0.2.130

## 0.2.2

### Patch Changes

- @scalar/oas-utils@0.2.129

## 0.2.1

### Patch Changes

- Updated dependencies [18b1be9]
  - @scalar/oas-utils@0.2.128

## 0.2.0

### Minor Changes

- 018e8b2: feat: import Postman post-response scripts

### Patch Changes

- 018e8b2: feat: cleaner Postman import (no 'default' tag, no made up responses)
- 018e8b2: fix: /raw and / paths are handled specifically
- Updated dependencies [bf961b1]
- Updated dependencies [a176b7e]
  - @scalar/oas-utils@0.2.127

## 0.1.49

### Patch Changes

- Updated dependencies [a571d36]
  - @scalar/oas-utils@0.2.126

## 0.1.48

### Patch Changes

- Updated dependencies [e62e677]
- Updated dependencies [e62e677]
- Updated dependencies [82f16a5]
- Updated dependencies [04e27a1]
- Updated dependencies [846d015]
  - @scalar/openapi-types@0.2.0
  - @scalar/oas-utils@0.2.125

## 0.1.47

### Patch Changes

- Updated dependencies [0de80ae]
  - @scalar/oas-utils@0.2.124

## 0.1.46

### Patch Changes

- Updated dependencies [52f6f4c]
  - @scalar/oas-utils@0.2.123

## 0.1.45

### Patch Changes

- @scalar/oas-utils@0.2.122

## 0.1.44

### Patch Changes

- Updated dependencies [0f13162]
- Updated dependencies [0212daa]
  - @scalar/oas-utils@0.2.121

## 0.1.43

### Patch Changes

- Updated dependencies [cd75eeb]
  - @scalar/oas-utils@0.2.120

## 0.1.42

### Patch Changes

- @scalar/oas-utils@0.2.119

## 0.1.41

### Patch Changes

- @scalar/oas-utils@0.2.118

## 0.1.40

### Patch Changes

- @scalar/oas-utils@0.2.117

## 0.1.39

### Patch Changes

- Updated dependencies [ab98841]
- Updated dependencies [db9ebbc]
  - @scalar/oas-utils@0.2.116

## 0.1.38

### Patch Changes

- @scalar/oas-utils@0.2.115

## 0.1.37

### Patch Changes

- Updated dependencies [fb22645]
  - @scalar/oas-utils@0.2.114

## 0.1.36

### Patch Changes

- Updated dependencies [a31973c]
  - @scalar/oas-utils@0.2.113

## 0.1.35

### Patch Changes

- @scalar/oas-utils@0.2.112

## 0.1.34

### Patch Changes

- Updated dependencies [89d8b75]
- Updated dependencies [8a04b8d]
- Updated dependencies [1459ce7]
- Updated dependencies [8a04b8d]
  - @scalar/oas-utils@0.2.111
  - @scalar/openapi-types@0.1.9

## 0.1.33

### Patch Changes

- @scalar/oas-utils@0.2.110

## 0.1.32

### Patch Changes

- Updated dependencies [4db5161]
  - @scalar/oas-utils@0.2.109

## 0.1.31

### Patch Changes

- Updated dependencies [9fc97da]
- Updated dependencies [12088f1]
- Updated dependencies [c10bbf5]
  - @scalar/oas-utils@0.2.108
  - @scalar/openapi-types@0.1.9

## 0.1.30

### Patch Changes

- Updated dependencies [e350f23]
- Updated dependencies [738d21c]
  - @scalar/openapi-types@0.1.8
  - @scalar/oas-utils@0.2.107

## 0.1.29

### Patch Changes

- Updated dependencies [ed92564]
  - @scalar/oas-utils@0.2.106

## 0.1.28

### Patch Changes

- fa6afe8: chore: code formatting
- 1223c1f: chore: code style
- Updated dependencies [54fdfcb]
  - @scalar/oas-utils@0.2.105
  - @scalar/openapi-types@0.1.7

## 0.1.27

### Patch Changes

- Updated dependencies [f500435]
- Updated dependencies [da5cf08]
- Updated dependencies [b5727ef]
- Updated dependencies [4de3124]
- Updated dependencies [34e6f52]
  - @scalar/oas-utils@0.2.104

## 0.1.26

### Patch Changes

- Updated dependencies [0f5df68]
- Updated dependencies [937f791]
  - @scalar/oas-utils@0.2.103

## 0.1.25

### Patch Changes

- Updated dependencies [a34f834]
- Updated dependencies [ef98b9c]
- Updated dependencies [a34f834]
- Updated dependencies [ebdf762]
- Updated dependencies [f9bf5f1]
  - @scalar/oas-utils@0.2.102
  - @scalar/openapi-types@0.1.7

## 0.1.24

### Patch Changes

- Updated dependencies [be34e7d]
  - @scalar/oas-utils@0.2.101

## 0.1.23

### Patch Changes

- Updated dependencies [12e7232]
- Updated dependencies [901970f]
- Updated dependencies [f1f39b0]
  - @scalar/oas-utils@0.2.100

## 0.1.22

### Patch Changes

- Updated dependencies [c803e2d]
  - @scalar/oas-utils@0.2.99

## 0.1.21

### Patch Changes

- @scalar/oas-utils@0.2.98

## 0.1.20

### Patch Changes

- Updated dependencies [7df4472]
- Updated dependencies [13333e6]
  - @scalar/oas-utils@0.2.97
  - @scalar/openapi-types@0.1.6

## 0.1.19

### Patch Changes

- Updated dependencies [cf0e7b1]
  - @scalar/oas-utils@0.2.96

## 0.1.18

### Patch Changes

- Updated dependencies [3156ecd]
  - @scalar/oas-utils@0.2.95

## 0.1.17

### Patch Changes

- Updated dependencies [a36fada]
  - @scalar/oas-utils@0.2.94

## 0.1.16

### Patch Changes

- Updated dependencies [ca2d98b]
  - @scalar/oas-utils@0.2.93

## 0.1.15

### Patch Changes

- Updated dependencies [02b4201]
  - @scalar/oas-utils@0.2.92

## 0.1.14

### Patch Changes

- @scalar/oas-utils@0.2.91

## 0.1.13

### Patch Changes

- Updated dependencies [573d113]
- Updated dependencies [c263aaf]
  - @scalar/oas-utils@0.2.90

## 0.1.12

### Patch Changes

- @scalar/oas-utils@0.2.89

## 0.1.11

### Patch Changes

- @scalar/oas-utils@0.2.88

## 0.1.10

### Patch Changes

- Updated dependencies [8017ff9]
  - @scalar/oas-utils@0.2.87

## 0.1.9

### Patch Changes

- Updated dependencies [3eb0d11]
- Updated dependencies [b66a85c]
  - @scalar/oas-utils@0.2.86

## 0.1.8

### Patch Changes

- eeb2a8b: fix: postman examples are misinterpreted as folders
- Updated dependencies [3b4a788]
- Updated dependencies [4c5be96]
- Updated dependencies [4c5be96]
  - @scalar/oas-utils@0.2.85

## 0.1.7

### Patch Changes

- Updated dependencies [9b4f85d]
  - @scalar/oas-utils@0.2.84

## 0.1.6

### Patch Changes

- Updated dependencies [f524411]
- Updated dependencies [10c9016]
- Updated dependencies [b11294c]
  - @scalar/oas-utils@0.2.83

## 0.1.5

### Patch Changes

- Updated dependencies [6389557]
  - @scalar/oas-utils@0.2.82

## 0.1.4

### Patch Changes

- @scalar/oas-utils@0.2.81

## 0.1.3

### Patch Changes

- @scalar/oas-utils@0.2.80

## 0.1.2

### Patch Changes

- Updated dependencies [6dd7eda]
  - @scalar/oas-utils@0.2.79

## 0.1.1

### Patch Changes

- Updated dependencies [daa2663]
- Updated dependencies [37abd4f]
  - @scalar/oas-utils@0.2.78

## 0.1.0

### Minor Changes

- a0bcd23: hello world :)

### Patch Changes

- Updated dependencies [44a7100]
  - @scalar/oas-utils@0.2.77
